@@ -1,7 +1,7 @@
 package App::PDRUtils::DistIniCmd;
 
-our $DATE = '2016-03-03'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2016-10-07'; # DATE
+our $VERSION = '0.07'; # VERSION
 
 use 5.010001;
 use strict;
@@ -33,14 +33,16 @@ App::PDRUtils::DistIniCmd - Common stuffs for App::PDRUtils::DistIniCmd::*
 
 =head1 VERSION
 
-This document describes version 0.06 of App::PDRUtils::DistIniCmd (from Perl distribution App-PDRUtils), released on 2016-03-03.
+This document describes version 0.07 of App::PDRUtils::DistIniCmd (from Perl distribution App-PDRUtils), released on 2016-10-07.
 
 =head1 DESCRIPTION
 
 A module under the L<App::PDRUtils::DistIniCmd> namespace represents a command
 that modifies F<dist.ini>. It is passed a parsed F<dist.ini> in the form of
 L<Config::IOD::Document> object and is expected to modify the object and return
-status 200 (along with the object), or return 304 if nothing is modified.
+status 200 (along with the object), or return 304 if nothing is modified. Result
+(if there is an output) can be returned in the result metadata in
+C<func.result> key).
 
 A DistIniCmd can easily be turned into a SingleCmd or MultiCmd.
 
