@@ -1,7 +1,7 @@
 package App::PDRUtils::SingleCmd;
 
-our $DATE = '2016-03-03'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2016-10-07'; # DATE
+our $VERSION = '0.07'; # VERSION
 
 use 5.010001;
 use strict;
@@ -69,6 +69,12 @@ sub create_cmd_from_dist_ini_cmd {
         } else {
             $log->tracef("%d - %s", $res->[0], $res->[1]);
         }
+
+        # move final result so users can see it
+        if (exists $res->[3]{'func.result'}) {
+            $res->[2] = delete $res->[3]{'func.result'};
+        }
+
         $res;
     };
 }
@@ -88,7 +94,7 @@ App::PDRUtils::SingleCmd - Common stuffs for App::PDRUtils::SingleCmd::*
 
 =head1 VERSION
 
-This document describes version 0.06 of App::PDRUtils::SingleCmd (from Perl distribution App-PDRUtils), released on 2016-03-03.
+This document describes version 0.07 of App::PDRUtils::SingleCmd (from Perl distribution App-PDRUtils), released on 2016-10-07.
 
 =head1 DESCRIPTION
 
